/*  -- translated by f2c (version 20100827).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__0 = 0;
static integer c__1 = 1;

/* ----------------------------------------------------------------------- */
/*     GBYTE */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int gbyte_(integer *npack, integer *iout, integer *ibit, 
	integer *nbits)
{
    extern /* Subroutine */ int gbytes_(integer *, integer *, integer *, 
	    integer *, integer *, integer *);

    /* Parameter adjustments */
    --npack;

    /* Function Body */
    gbytes_(&npack[1], iout, ibit, nbits, &c__0, &c__1);
    return 0;
} /* gbyte_ */

